class HashVariables:
    @classmethod
    def ExcheckUpdate(cls):
        cls.INTAG = None
        return cls

